@@ -7,6 +7,7 @@ import bisect
 # from tqdm import tqdm
 from datetime import datetime, timedelta
 from microt_compliance_matrix import utils
+from microt_compliance_matrix.utils.get_time_diff import *
 
 from microt_compliance_matrix.utils.uncompress_file import *
 
@@ -142,7 +143,6 @@ def find_closest_time(prompt_time, subset_time_list):
     closet_time = min(subset_time_list[max(0, i - 1): i + 2], key=lambda t: abs(prompt_time - t))
     return closet_time
 
-
 def match_feature(prompt_local_datetime_series, df_logs_combined):
 
     print("     --- start matching")
@@ -162,11 +162,15 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
 
             closest_time = find_closest_time(prompt_time, subset_time_list)
 
-            lat = list(df_logs_combined[df_logs_combined['LOCATION_TIME_DATETIME'] == closest_time][
-                                     "LAT"])[0]
-            long = list(df_logs_combined[df_logs_combined['LOCATION_TIME_DATETIME'] == closest_time][
-                                       "LONG"])[0]
-            location = [lat, long]
+            # check if matched time is 5 minutes away from prompt time
+            if get_min_diff(prompt_time, closest_time) < 5:
+                lat = list(df_logs_combined[df_logs_combined['LOCATION_TIME_DATETIME'] == closest_time][
+                                         "LAT"])[0]
+                long = list(df_logs_combined[df_logs_combined['LOCATION_TIME_DATETIME'] == closest_time][
+                                           "LONG"])[0]
+                location = [lat, long]
+            else:
+                location = np.nan
 
         matched_time_list.append(closest_time)
         matched_location_list.append(location)
